<?php

/* Translations can be filed in the /languages/ directory */

load_theme_textdomain( 'two2', TEMPLATEPATH . '/languages' );

$locale = get_locale();
$locale_file = TEMPLATEPATH . "/languages/$locale.php";
if ( is_readable($locale_file) )
    require_once($locale_file);


/* Tell WordPress to run two2_setup() when the 'after_setup_theme' hook is run. */
add_action( 'after_setup_theme', 'two2_theme_setup' );

if ( ! function_exists( 'two2_theme_setup' ) ):

function two2_theme_setup() {

	if(is_admin()){	
		require_once(TEMPLATEPATH. '/functions/two2-theme-settings.php');
	}
		
	// This theme uses post thumbnails
	add_theme_support( 'post-thumbnails' );
	
	// Images size
	if ( function_exists( 'add_image_size' ) ) { 
		
		set_post_thumbnail_size( 450, 300, true );
		add_image_size('featured-thumbnail', 100, 66, true);
		add_image_size('large-slideshow', 1280, 2000, false);
	}

	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );
	
	if ( ! isset( $content_width ) ) 
    $content_width = 900;
    
}
endif;


if ( function_exists( 'register_nav_menus' ) ) {
	register_nav_menus(
		array(
		  'two2_main' => __("Main sections menu","two2"),
		)
	);
}



/* Remove unnecessary menus */
add_action( 'admin_menu', 'two2_remove_menu_pages' );
function two2_remove_menu_pages() {
	//only for WordPress 3.1+
	if(function_exists('remove_menu_page')){
		remove_menu_page('link-manager.php'); // Links
		remove_menu_page('edit-comments.php'); // Comments
		remove_submenu_page('options-general.php','options-discussion.php');
	}
}


/* Custom body classes */
add_filter('body_class','two2_body_classes');
function two2_body_classes($classes) {
	$two2_option = two2_get_global_options();
	$classes[] = 'col-size-'.$two2_option['two2_home_thumbs_size'];
	$classes[] = $two2_option['two2_nav_location'];
	$classes[] = $two2_option['two2_gallery_type'];
	$classes[] = $two2_option['two2_main_layout'];
	$classes[] = $two2_option['two2_fixed_nav'];
	$classes[] = 'thumb-opacity-'.($two2_option['two2_home_thumbs_opacity']/100);
	return $classes;
}

function two2_admin_body_classes($classes) {
	$two2_option = two2_get_global_options();

	global $post;
	$mode = '';
	$uri = $_SERVER["REQUEST_URI"];
	if(isset($post)){
		$post_type = get_post_type($post->ID);
		if (strstr($uri,'edit.php')) {
			$mode = 'edit-list-';
		}
		if (strstr($uri,'post.php')) {
			$mode = 'edit-page-';
		}
		$classes .= $two2_option['two2_nav_location'].' '.$two2_option['two2_gallery_type'] . ' '.$mode . $post_type;
	} else {
		if(strstr($uri,'two2-settings')){
			$classes .= 'folio-two-settings';
		}
	}
	return $classes;
}
add_filter( 'admin_body_class', 'two2_admin_body_classes' );


/* Remove dimension attributes from homepage thumbnails */
add_filter( 'post_thumbnail_html', 'remove_thumbnail_dimensions', 10, 3 );

function remove_thumbnail_dimensions( $html, $post_id, $post_image_id ) {
    $html = preg_replace( '/(width|height)=\"\d*\"\s/', "", $html );
    return $html;
}


/* Add custom taxonomies to the post class */
add_filter( 'post_class', 'custom_taxonomy_post_class', 10, 3 );

if( !function_exists( 'custom_taxonomy_post_class' ) ) {
    function custom_taxonomy_post_class( $classes, $class, $ID ) {
        $taxonomy = 'portfolio_type';
        $terms = get_the_terms( (int) $ID, $taxonomy );
        if( !empty( $terms ) ) {
            foreach( (array) $terms as $order => $term ) {
                if( !in_array( $term->slug, $classes ) ) {
                    $classes[] = 'cat-'.$term->slug;
                }
            }
        }
        return $classes;
    }
}  



/* Add new thumbnail column in project list */
function two2_columns_head($defaults) {
	$defaults['project_image'] = __("Project Image","two2");
	$defaults['project_client'] = __("Client","two2");
	return $defaults;
}
function two2_columns_content($column_name, $post_ID) {
	if ($column_name == 'project_image') {
		$project_image = two2_get_featured_image($post_ID);
		if ($project_image) {
			echo '<img width="100" src="' . $project_image . '" />';
		}
	}
	
	if ($column_name == 'project_client') {
		$project_client = get_post_meta($post_ID, 'project_client', true);
		if ($project_client) {
			echo $project_client;
		}
	}
}
add_filter('manage_posts_columns', 'two2_columns_head');
add_action('manage_posts_custom_column', 'two2_columns_content', 10, 2);


/* Get featured image */
function two2_get_featured_image($post_ID) {
	$post_thumbnail_id = get_post_thumbnail_id($post_ID);
	if ($post_thumbnail_id) {
		$post_thumbnail_img = wp_get_attachment_image_src($post_thumbnail_id, 'featured-thumbnail');
		return $post_thumbnail_img[0];
	}
}


/* Get YouTube video ID from the URL */
function two2_get_youtube_ID($url){
	preg_match('#(\.be/|/embed/|/v/|/watch\?v=)([A-Za-z0-9_-]{5,11})#', $url, $matches);
	if(isset($matches[2]) && $matches[2] != ''){
	     return $matches[2];
	}
}

/* Get Vimeo video ID from the URL */
function two2_get_vimeo_ID($url){
	preg_match_all('#(http://vimeo.com)/([0-9]+)#i',$url,$output);
	return $output[2][0];
}



/* Get all the project media for the slider */

function two2_get_project_media($size='thumbnail', $sizelarge='large-slideshow', $jumpfeat=false) {
	$args = array(
	'post_type' => 'attachment',
	'orderby' => 'menu_order',
	'order' => 'ASC',
	'numberposts' => -1,
	'post_mime_type' => 'image',
	'post_status' => null,
	'post_parent' => get_the_ID()
	);
	$images_array = array();
	if($jumpfeat){ $featatid = get_post_thumbnail_id(); } else { $featatid=0; }
	$attachments = get_posts($args);
	if ($attachments) {
		$num_image=0;
		$array_pos=0;
		foreach ($attachments as $attachment) {
			$imatge_thumb = wp_get_attachment_image_src($attachment->ID, $size);
			$imatge_large = wp_get_attachment_image_src($attachment->ID, $sizelarge);
			$url[$num_image] = $imatge_thumb[0];
			$title[$num_image] = $attachment->post_title;
			$url_source[$num_image] = $imatge_large[0];
			$alt[$num_image] = $attachment->post_content;
			
			if(($attachment->ID != $featatid && $jumpfeat==true) || $jumpfeat==false){
				$images_array[$array_pos][0] = $attachment->ID;
				$images_array[$array_pos][1] = $url[$num_image];
				$images_array[$array_pos][2] = $url_source[$num_image];
				$images_array[$array_pos][3] = $alt[$num_image];
				$array_pos++;
			}
			$num_image++;
		}
	}
	return $images_array;
}


/* Retrieve the post number and give it format */

function two2_get_post_number($post,$orderby){
	if($orderby=='post_date'){
		$projects = get_posts('post_status=publish&post_type=portfolio&numberposts=-1&orderby=post_date&order=desc'); 
		$projectsids = array();
		foreach($projects as $project) {
			$projectsids[] = $project->ID;
		}
		$key = array_search($post->ID, $projectsids)+1; 
	} else {
		$key = $post->menu_order;
	}
	return str_pad($key, strlen(count($projects)), "0", STR_PAD_LEFT);
}


function two2_get_total_posts_number($post){
	$projects = get_posts('post_status=publish&post_type=portfolio&numberposts=-1'); 
	return str_pad(count($projects), strlen(count($projects)), "0", STR_PAD_LEFT);
}



/* Get the post term slugs */ 

function two2_get_post_terms_slugs($taxonomy){
	$terms = get_the_terms(get_the_ID(), $taxonomy); 
    if($terms && ! is_wp_error($terms)){
		$term_slugs = array();
		foreach ($terms as $term){
			$term_slugs[] = $term->slug;
		}
		return $term_slugs;
	}						
}
				

/* Check if attachment is a video URL */

function two2_attachment_is_video($attachment_id){
	if(get_post_meta($attachment_id, '_url_video_vimeo', true) || get_post_meta($attachment_id, '_url_video_youtube', true) || get_post_meta($attachment_id, '_url_video_mp4', true) || get_post_meta($attachment_id, '_url_video_webm', true) || get_post_meta($attachment_id, '_url_video_ogg', true)){ 
		return true;
	} else {
		return false;
	}
}

/* Retrieve the attachment link */ 

function two2_get_media_link($media){
	if(two2_attachment_is_video($media[0])){ 
		if(get_post_meta($media[0], '_url_video_youtube', true)){ 
			return "http://www.youtube.com/watch?v=".two2_get_youtube_ID(get_post_meta($media[0], '_url_video_youtube', true)); } 
		elseif(get_post_meta($media[0], '_url_video_vimeo', true)){ 
			return "http://www.vimeo.com/".two2_get_vimeo_ID(get_post_meta($media[0], '_url_video_vimeo', true)); 
		} 
	} else { 
		return $media[2]; 
	}
}
            			

/* PORTFOLIO Hide Insert Gallery Button */

add_action( 'admin_head_media_upload_gallery_form', 'two2_remove_gallery_setting_div' );
if( !function_exists( 'mfields_remove_gallery_setting_div' ) ) {
    function two2_remove_gallery_setting_div() {
    	if('portfolio' == get_post_type($_GET['post_id'])){
        print '
            <style type="text/css">
                #gallery-settings *,
                tr.url,
	            tr.image-size,
	            tr.align,
	            .savesend .button[type="submit"],
	            tr.image_alt{
                display:none;
                }
            </style>';
        }
    }
}



// ===================== 
// ! AJAX  
// ===================== 

add_action('wp_ajax_nopriv_two2_send_contact_form', 'two2_send_contact_form');
add_action('wp_ajax_two2_send_contact_form', 'two2_send_contact_form');

function two2_send_contact_form(){
	$two2_option = two2_get_global_options();
	$name = $_POST['name'];
	$email = $_POST['email'];
	$message = $_POST['message'];
	
	$subject = "Message from your portfolio";
	$body = "From $name, \n\n$email, \n\n$message";
	
	$to = $two2_option['two2_contact_email'];
	
	$result = mail($to, $subject, $body);
	
	if($result){ 
		print "<h3>".__("Success","two2")."</h3><p>".__("Your email has been sent!","two2")."</p>"; 
	} else {  
		print "<h3>".__("Error","two2")."</h3><p>".__("Try it again later, please.","two2")."</p>"; 
	}

	die();
}




function vankarwai_get_google_webfont($font){
	
	$fontprefix = '<link rel="stylesheet" type="text/css" href="http://fonts.googleapis.com/css?family=';
	$fontsufix = '">';
	$import='';	
	
	
	if($font=='Abel'){
		$import = $fontprefix."Abel".$fontsufix;
	}
	if($font=='Abril Fatface'){
		$import = $fontprefix."Abril+Fatface".$fontsufix;
	}
	if($font=='Advent Pro'){
		$import = $fontprefix."Advent+Pro:100,200,300,400,500,600,700".$fontsufix;
	}
	if($font=='Alfa Slab One'){
		$import = $fontprefix."Alfa+Slab+One".$fontsufix;
	}
	if($font=='Alice'){
		$import = $fontprefix."Alice".$fontsufix;
	}
	if($font=='Alike'){
		$import = $fontprefix."Alike".$fontsufix;
	}
	if($font=='Antic'){
		$import = $fontprefix."Antic".$fontsufix;
	}
	if($font=='Artifika'){
		$import = $fontprefix."Artifika".$fontsufix;
	}
	if($font=='Arvo'){
		$import = $fontprefix."Arvo:400,700,400italic,700italic".$fontsufix;
	}
	if($font=='Balthazar'){
		$import = $fontprefix."Balthazar".$fontsufix;
	}
	if($font=='Bevan'){
		$import = $fontprefix."Bevan".$fontsufix;
	}
	if($font=='Bowlby One SC'){
		$import = $fontprefix."Bowlby+One+SC".$fontsufix;
	}
	if($font=='Bree Serif'){
		$import = $fontprefix."Bree+Serif".$fontsufix;
	}
	if($font=='Cabin'){
		$import = $fontprefix."Cabin:400,500,600,700,400italic,500italic,600italic,700italic".$fontsufix;
	}
	if($font=='Cantata One'){
		$import = $fontprefix."Cantata+One".$fontsufix;
	}
	if($font=='Carme'){
		$import = $fontprefix."Carme".$fontsufix;
	}
	if($font=='Condiment'){
		$import = $fontprefix."Condiment".$fontsufix;
	}
	if($font=='Coustard'){
		$import = $fontprefix."Coustard:400,900".$fontsufix;
	}
	if($font=='Crete Round'){
		$import = $fontprefix."Crete+Round:400,400italic".$fontsufix;
	}
	if($font=='Cutive'){
		$import = $fontprefix."Cutive".$fontsufix;
	}
	if($font=='Dosis'){
		$import = $fontprefix."Dosis".$fontsufix;
	}
	if($font=='Economica'){
		$import = $fontprefix."Economica:400,700,400italic,700italic".$fontsufix;
	}
	if($font=='Fjord One'){
		$import = $fontprefix."Fjord+One".$fontsufix;
	}
	if($font=='Flamenco'){
		$import = $fontprefix."Flamenco:300,400".$fontsufix;
	}
	if($font=='Glass Antiqua'){
		$import = $fontprefix."Glass+Antiqua".$fontsufix;
	}
	if($font=='Glegoo'){
		$import = $fontprefix."Glegoo".$fontsufix;
	}
	if($font=='Gravitas One'){
		$import = $fontprefix."Gravitas+One".$fontsufix;
	}
	if($font=='Holtwood One SC'){
		$import = $fontprefix."Holtwood+One+SC".$fontsufix;
	}
	if($font=='IM Fell DW Pica SC'){
		$import = $fontprefix."IM+Fell+DW+Pica+SC".$fontsufix;
	}
	if($font=='Inika'){
		$import = $fontprefix."Inika:400,700".$fontsufix;
	}
	if($font=='Josefin Sans'){
		$import = $fontprefix."Josefin+Sans:100,300,400,600,700,100italic,300italic,400italic,600italic,700italic".$fontsufix;
	}
	if($font=='Kameron'){
		$import = $fontprefix."Kameron:400,700".$fontsufix;
	}
	if($font=='Kelly Slab'){
		$import = $fontprefix."Kelly+Slab".$fontsufix;
	}
	if($font=='Lancelot'){
		$import = $fontprefix."Lancelot".$fontsufix;
	}
	if($font=='Lekton'){
		$import = $fontprefix."Lekton:400,700,400italic".$fontsufix;
	}
	if($font=='Limelight'){
		$import = $fontprefix."Limelight".$fontsufix;
	}
	if($font=='Linden Hill'){
		$import = $fontprefix."Linden+Hill:400,400italic".$fontsufix;
	}
	if($font=='Lobster Two'){
		$import = $fontprefix."Lobster+Two:400,400italic,700,700italic".$fontsufix;
	}
	if($font=='Lustria'){
		$import = $fontprefix."Lustria".$fontsufix;
	}
	if($font=='Maven Pro'){
		$import = $fontprefix."Maven+Pro:400,500,700,900".$fontsufix;
	}
	if($font=='Megrim'){
		$import = $fontprefix."Megrim".$fontsufix;
	}
	if($font=='Molengo'){
		$import = $fontprefix."Molengo".$fontsufix;
	}
	if($font=='Nobile'){
		$import = $fontprefix."Nobile:400,400italic,700,700italic".$fontsufix;
	}
	if($font=='Noticia Text'){
		$import = $fontprefix."Noticia+Text:400,400italic,700,700italic".$fontsufix;
	}
	if($font=='Old Standard TT'){
		$import = $fontprefix."Old+Standard+TT:400,400italic,700".$fontsufix;
	}
	if($font=='Oldenburg'){
		$import = $fontprefix."Oldenburg".$fontsufix;
	}
	if($font=='Patua One'){
		$import = $fontprefix."Patua+One".$fontsufix;
	}
	if($font=='Paytone One'){
		$import = $fontprefix."Paytone+One".$fontsufix;
	}
	if($font=='Playfair Display'){
		$import = $fontprefix."Playfair+Display:400,400italic".$fontsufix;
	}
	if($font=='Poiret One'){
		$import = $fontprefix."Poiret+One".$fontsufix;
	}
	if($font=='Port Lligat Slab'){
		$import = $fontprefix."Port+Lligat+Slab".$fontsufix;
	}
	if($font=='PT Sans Narrow'){
		$import = $fontprefix."PT+Sans+Narrow:400,700".$fontsufix;
	}
	if($font=='PT Serif'){
		$import = $fontprefix."PT+Serif:400,700,400italic,700italic".$fontsufix;
	}
	if($font=='Radley'){
		$import = $fontprefix."Radley:400,400italic".$fontsufix;
	}
	if($font=='Raleway'){
		$import = $fontprefix."Raleway:100".$fontsufix;
	}
	if($font=='Rokkitt'){
		$import = $fontprefix."Rokkitt:400,700".$fontsufix;
	}
	if($font=='Satisfy'){
		$import = $fontprefix."Satisfy".$fontsufix;
	}
	if($font=='Seaweed Script'){
		$import = $fontprefix."Seaweed+Script".$fontsufix;
	}
	if($font=='Simonetta'){
		$import = $fontprefix."Simonetta:400,400italic".$fontsufix;
	}
	if($font=='Sonsie One'){
		$import = $fontprefix."Sonsie+One".$fontsufix;
	}
	if($font=='Sorts Mill Goudy'){
		$import = $fontprefix."Sorts+Mill+Goudy:400,400italic".$fontsufix;
	}
	if($font=='Stint Ultra Expanded'){
		$import = $fontprefix."Stint+Ultra+Expanded".$fontsufix;
	}
	if($font=='Tienne'){
		$import = $fontprefix."Tienne:400,700,900".$fontsufix;
	}
	if($font=='Tinos'){
		$import = $fontprefix."Tinos:400,700,400italic,700italic".$fontsufix;
	}
	if($font=='Ultra'){
		$import = $fontprefix."Ultra".$fontsufix;
	}
	if($font=='Vidaloka'){
		$import = $fontprefix."Vidaloka".$fontsufix;
	}
	
	
	return $import;
}



function vankarwai_get_font_css($name){
	$two2_option = two2_get_global_options();
	if(isset($two2_option[$name]['uppercase']) && $two2_option[$name]['uppercase']==1){ $uppercase = 'uppercase'; } else { $uppercase = 'none'; }
	if(isset($two2_option[$name]['italic']) && $two2_option[$name]['italic']==1){ $italic = 'italic'; } else { $italic = 'normal'; }
	
	if(isset($two2_option[$name]['face'])){ $css =  'font-family: '.$two2_option[$name]['face'].'; '; }
	if(isset($two2_option[$name]['size'])) { $css .= 'font-size: '.$two2_option[$name]['size'].'; '; }
	if(isset($two2_option[$name]['weight'])) { $css .= 'font-weight: '.$two2_option[$name]['weight'].'; '; }
	if(isset($two2_option[$name]['color'])){ $css .= 'color: '.$two2_option[$name]['color'].'; '; }
	if(isset($two2_option[$name]['uppercase']) && $two2_option[$name]['uppercase']!=''){ $css .= 'text-transform: '.$uppercase.'; '; }
	if(isset($two2_option[$name]['italic']) && $two2_option[$name]['italic']!=''){ $css .= 'font-style: '.$italic.';'; }
	
	return $css;
}





/**
 * Collects our theme options
 *
 * @return array
 */
function two2_get_global_options(){

	$two2_option = array();

	// collect option names as declared in two2_get_settings()
	$two2_option_names = array (
		'two2_options',
		'two2_options_style',
		'two2_options_project',
		'two2_options_fonts',
		'two2_options_pages'
	);

	// loop for get_option
	foreach ($two2_option_names as $two2_option_name) {
		if (get_option($two2_option_name)!= FALSE) {
			$option 	= get_option($two2_option_name);

			// now merge in main $two2_option array!
			$two2_option = array_merge($two2_option, $option);
		} 
	}	

return $two2_option;
}





if(!function_exists('next_post_link_plus')){ include(TEMPLATEPATH. '/includes/ambrosite-post-link-plus.php'); }

require_once(TEMPLATEPATH. '/functions/two2-theme-enqueues.php');
require_once(TEMPLATEPATH. '/functions/two2-theme-custom-post-types.php');
require_once(TEMPLATEPATH. '/functions/two2-theme-custom-fields.php');

?>
