<?php
/**
 * Define our settings sections
 *
 * array key=$id, array value=$title in: add_settings_section( $id, $title, $callback, $page );
 * @return array
 */
function two2_options_style_sections() {
	
	$sections = array();
	$sections['top_bar'] 			= __('Top Bar Options', 'two2');
	$sections['nav_bar'] 			= __('Navigation Bars Options', 'two2');
	$sections['general_style'] 		= __('General Style Options', 'two2');
	
	return $sections;	
} 

/**
 * Define our form fields (settings) 
 *
 * @return array
 */
function two2_options_style_fields() {

	$options = array (
		
		array(	"section"	=> "top_bar",
				"type" 		=> "image",
				"name" 		=> "two2_custom_logo",
				"title" 	=> __("Custom Top Bar Logo","two2"),
				"std"	=> get_template_directory_uri().'/images/top-bar.png',
				"desc"		=> __("Upload a logo or specify the image URL of your on-line logo. Max dimensions: 220px width x 40px height. Note you should click on 'Insert to post' button in order to insert the image correctly.","two2"),
				"in_style"	=> "background: black;padding:5px;"),
				
		array(	"section"	=> "nav_bar",
				"type" 		=> "image",
				"name" 		=> "two2_custom_logo_nav",
				"title" 	=> __("Custom Navigation Bar Logo","two2"),
				"std"	=> get_template_directory_uri().'/images/main-logo.png',
				"desc"		=> __("Upload a logo or specify the image URL of your on-line logo. Note you should click on 'Insert to post' button in order to insert the image correctly.","two2"),
				"style"		=> "width:300px;",
				"in_style"	=> "background:url(".get_option('two2_nav_pattern').");padding:5px"),
		
		array(	"section"	=> "nav_bar",
				"type" 		=> "select",
				"name" 		=> "two2_nav_align",
				"title" 	=> __("Navigation Alignment","two2"),
				"choices" 	=> array(__("Align Left","two"), __("Align Right","two"), __("Align Center","two")),
				"values" 	=> array(3,1,2),
				"std" 	=> 1),
				
		array(	"section"	=> "nav_bar",
				"type" 		=> "select",
				"name" 		=> "two2_fixed_nav",
				"title" 	=> __("Fixed Navigation","two2"),
				"choices" 	=> array(__("Slide Navigation, No Fixed","two"), __("Fixed Navigation","two")),
				"values" 	=> array('slide-nav','fixed-nav'),
				"std" 	=> 'slide-nav'),
	
		array(	"section"	=> "nav_bar",
				"type" 		=> "slider",
				"name" 		=> "two2_logo_nav_horizontal_position",
				"title" 	=> __("Nav Bar Logo Horizontal Position","two2"),
				"values" 	=> array(-250,250),	
				"std"	=> 30,
				"desc"		=> __("A positive value will move the logo to the right. A negative one, will move it to the left.","two2")),
				
		array(	"section"	=> "nav_bar",
				"type" 		=> "slider",
				"name" 		=> "two2_logo_nav_vertical_position",
				"title" 	=> __("Nav Bar Logo Vertical Position","two2"),
				"values" 	=> array(-500,500),
				"std"	=> 120,
				"desc"		=> __("A positive value will move the logo up. A negative one, will move it down.","two2")),
		
		array(	"section"	=> "nav_bar",
				"type" 		=> "slider",
				"name" 		=> "two2_nav_vertical_position",
				"title" 	=> __("Left Nav Vertical Position","two2"),
				"values" 	=> array(-250,250),
				"std"	=> 20,
				"desc"		=> __("A positive value will move the navigation content up. A negative one, will move it down.","two2")),
				
		array(	"section"	=> "nav_bar",
				"type" 		=> "bgbuttons",
				"name" 		=> "two2_nav_pattern",
				"name_sec"	=> "two2_nav_custom_pattern",
				"title" 	=> __("Nav Background Pattern","two2"),
				"title_sec"	=> __("Nav Custom Background Pattern","two2"),
				"values" 	=> array(	get_template_directory_uri().'/images/backgrounds/pattern.jpg',
										get_template_directory_uri().'/images/backgrounds/pattern-nav-01.png',
										get_template_directory_uri().'/images/backgrounds/pattern-nav-02.png',
										get_template_directory_uri().'/images/backgrounds/pattern-nav-03.jpg',
										get_template_directory_uri().'/images/backgrounds/pattern-nav-04.jpg',
										get_template_directory_uri().'/images/backgrounds/pattern-nav-05.jpg',
										get_template_directory_uri().'/images/backgrounds/pattern-nav-06.jpg',
										get_template_directory_uri().'/images/backgrounds/pattern-nav-07.png',
										get_template_directory_uri().'/images/backgrounds/pattern-nav-08.jpg'
								),
				"std"	=> get_template_directory_uri().'/images/backgrounds/pattern.jpg'),
				
		array(	"section"	=> "nav_bar",
				"type" 		=> "imagenopreview",
				"name" 		=> "two2_nav_pattern_custom",
				"title" 	=> __("Custom Nav Background Pattern","two2"),
				"desc"		=> __("Upload an image or a pattern for your navigation bar background. Note you should click the 'Insert to post' button in order to insert the image correctly.","two2")),
				
		array(	"section"	=> "nav_bar",
				"type" 		=> "imagebuttons",
				"name" 		=> "two2_btn_arrow_left",
				"name_sec"	=> "two2_custom_btn_arrow_left",
				"title" 	=> __("Open Nav Left Image","two2"),
				"title_sec" => __("Open Nav Left Custom Image","two2"),
				"values" 	=> array(	get_template_directory_uri().'/images/tab-nav-single.png',
										get_template_directory_uri().'/images/skins-items/tab-nav-blumarine.png',
										get_template_directory_uri().'/images/skins-items/tab-nav-green.png',
										get_template_directory_uri().'/images/skins-items/tab-nav-orange.png'
							),
				"std" 	=> get_template_directory_uri().'/images/tab-nav-single.png'),
								
		array(	"section"	=> "nav_bar",
				"type" 		=> "imagenopreview",
				"name" 		=> "two2_btn_arrow_left_custom",
				"title" 	=> __("Custom Open Nav Left Image","two2"),
				"desc"		=> __("Upload an image or a pattern for your navigation bar background. Note you should click the 'Insert to post' button in order to insert the image correctly.","two2")),
				
		array(	"section"	=> "nav_bar",
				"type" 		=> "imagebuttons",
				"name" 		=> "two2_btn_open_top",
				"name_sec"	=> "two2_custom_btn_open_top",
				"title" 	=> __("Open Tov Nav Image","two2"),
				"title_sec" => __("Custom Open Top Nav Image","two2"),
				"values" 	=> array(	get_template_directory_uri().'/images/btn-open-top-nav.png',
										get_template_directory_uri().'/images/skins-items/btn-open-top-nav-orange.png'
							),
				"std" 	=> get_template_directory_uri().'/images/btn-open-top-nav.png',
				"desc"		=> __("Choose an image for the button that open the top navigation menu. Note that this top navigation is only available when the top navigation layout is enabled. This button is also showed in all portable devices.","two2")),
				
		array(	"section"	=> "nav_bar",
				"type" 		=> "imagenopreview",
				"name" 		=> "two2_btn_open_top_custom",
				"title" 	=> __("Custom Open Tov Nav Image","two2")),
				
		array(	"section"	=> "nav_bar",
				"type" 		=> "imagebuttons",
				"name" 		=> "two2_btn_top_close",
				"title" 	=> __("Close Top Nav Image","two2"),
				"title_sec" => __("Custom Close Top Nav Image","two2"),
				"values" 	=> array(	get_template_directory_uri().'/images/btn-close-top-nav.png'
							),
				"std"	=> get_template_directory_uri().'/images/btn-close-top-nav.png'),
				
		array(	"section"	=> "nav_bar",
				"type" 		=> "imagenopreview",
				"name" 		=> "two2_btn_top_close_custom",
				"title" 	=> __("Custom Close Top Nav Image","two2"),
				"desc"		=> __("Choose an image for the button that close the top navigation menu.","two2")),
										
		array(	"section"	=> "general_style",
				"type" 		=> "image",
				"name" 		=> "two2_custom_favicon",
				"title" 	=> __("Custom Favicon","two2"),
				"desc"		=> __("Upload a 16x16px PNG/GIF that will represent your website's favicon.","two2"),
				"style"		=> "width: 16px; overflow: hidden;"),
	
		array(	"section"	=> "general_style",
				"type" 		=> "imageselect",
				"name" 		=> "two2_main_layout",
				"title" 	=> __("Main Layout","two2"),
				"choices" 	=> array(__('Advanced','two2'),__('Lightbox','two2')),
				"values" 	=> array('layout-1','layout-2'),
				"std" 	=> 'layout-1',
				"desc"		=> __("Choose between an advanced layout with custom galleries or a simple one working with lightbox.","two2")),
		
		array(	"section"	=> "general_style",
				"type" 		=> "imageselect",
				"name" 		=> "two2_nav_location",
				"title" 	=> __("Navigation Type","two2"),
				"choices" 	=> array(__('Left Navigation','two2'),__('Top Navigation','two2')),
				"values" 	=> array('left-nav','top-nav'),
				"std" 	=> 'left-nav',
				"desc"		=> __("Choose the location of the main site navigation.","two2")),	
				
		array(	"section"	=> "general_style",
				"type" 		=> "color",
				"name" 		=> "two2_main_color",
				"std"	=> "#ffff00",
				"title" 	=> __("Main Color","two2")),
				
		array(	"section"	=> "general_style",
				"type" 		=> "color",
				"name" 		=> "two2_text_main_color",
				"std"	=> "#414141",
				"title" 	=> __("Text Main Color","two2")),	
		/*
		array(	"section"	=> "general_style",
				"type" 		=> "imagebuttons",
				"name" 		=> "two2_btn_close_page",
				"name_sec"	=> "two2_custom_btn_close_page",
				"title" 	=> __("Close Page Image","two2"),
				"title_sec" => __("Custom Close Page Image","two2"),
				"values" 	=> array(	get_template_directory_uri().'/images/btn-close-black.png'
							),
				"std" 	=> get_template_directory_uri().'/images/btn-close-black.png',
				"desc"		=> __("Choose an image for the button that close the pages like news and about.","two2")),
		
		array(	"section"	=> "general_style",
				"type" 		=> "imagenopreview",
				"name" 		=> "two2_btn_close_page_custom",
				"title" 	=> __("Close Page Image","two2")),
		*/
		array(	"section"	=> "general_style",
				"type" 		=> "slider",
				"name" 		=> "two2_home_thumbs_size",
				"title" 	=> __("Homepage Thumbnails Size","two2"),
				"values" 	=> array(50,450),
				"std" 	=> 225),	
				
		array(	"section"	=> "general_style",
				"type" 		=> "slider",
				"name" 		=> "two2_home_thumbs_opacity",
				"title" 	=> __("Homepage Thumbnails Opacity","two2"),
				"values" 	=> array(0,100),
				"unit"		=> '%',
				"std" 	=> 40),	
				
		array(	"section"	=> "general_style",
				"type" 		=> "textareacode",
				"name" 		=> "two2_css_code",
				"title" 	=> __("Custom CSS","two2"),
				"desc"		=> __("Insert here your custom CSS code to overwrite the theme's one.","two2"))
							
	);
		
	return $options;

}

?>