<?php
/**
 * Define Constants
 */
define('TWO2_PAGE_BASENAME', 'two2-settings'); 


function two2_set_default_options() {
	$two2_default_options = array();
	$two2_default_options_style = array();
	$two2_default_options_project = array();
	$two2_default_options_fonts = array();
	$two2_default_options_pages = array();
				
	foreach(two2_options_fields() as $val){
   		$two2_default_options[$val['name']] = $val['std'];
	}
	update_option('two2_options',$two2_default_options);
	
	
	foreach(two2_options_style_fields() as $val){
   		$two2_default_options_style[$val['name']] = $val['std'];
	}
	update_option('two2_options_style',$two2_default_options_style);
	
	
	foreach(two2_options_project_fields() as $val){
   		$two2_default_options_project[$val['name']] = $val['std'];
	}
	update_option('two2_options_project',$two2_default_options_project);
	
	
	foreach(two2_options_fonts_fields() as $val){
   		$two2_default_options_fonts[$val['name']] = $val['std'];
	}
	update_option('two2_options_fonts',$two2_default_options_fonts);
	
	foreach(two2_options_pages_fields() as $val){
   		$two2_default_options_pages[$val['name']] = $val['std'];
	}
	update_option('two2_options_pages',$two2_default_options_pages);
	
}

function two2_first_run_options() {
	if ( get_option('two2_activation_check') != "set" ) {
		two2_set_default_options();
   		add_option('two2_activation_check', "set");
  	}
}
add_action('wp_head', 'two2_first_run_options');
add_action('admin_head', 'two2_first_run_options');


/**
 * Specify Hooks/Filters
 */
add_action( 'admin_menu', 'two2_add_menu' );
add_action( 'admin_init', 'two2_register_settings' );

/**
 * Include the required files
 */
// page settings sections & fields
require_once('two2-theme-options.php');
require_once('two2-theme-options-style.php');
require_once('two2-theme-options-project.php');
require_once('two2-theme-options-fonts.php');
require_once('two2-theme-options-pages.php');

 /**
 * Helper function for defining variables according to current page content
 *
 * @return array
 */
function two2_get_settings() {
	
	$output = array();
	
	/*PAGES*/
	// get current page
	$page = two2_get_admin_page();

	if(substr($page,0,4)=='two2'){
		/*DEFINE VARS*/
		// define variables according to registered admin menu page: two2_add_menu()
		switch ($page) {
			case TWO2_PAGE_BASENAME:
				$two2_option_name 		= 'two2_options';
				$two2_settings_page_title = __( 'General','two2');	
				$two2_page_sections 		= two2_options_sections();
				$two2_page_fields 		= two2_options_fields();
			break;
		
			case TWO2_PAGE_BASENAME . '-project':
				$two2_option_name 		= 'two2_options_project';
				$two2_settings_page_title = __( 'Project','two2');
				$two2_page_sections 		= two2_options_project_sections();
				$two2_page_fields 		= two2_options_project_fields();
			break;
			
			case TWO2_PAGE_BASENAME . '-fonts':
				$two2_option_name 		= 'two2_options_fonts';
				$two2_settings_page_title = __( 'Fonts','two2');
				$two2_page_sections 		= two2_options_fonts_sections();
				$two2_page_fields 		= two2_options_fonts_fields();
			break;
			
			case TWO2_PAGE_BASENAME . '-pages':
				$two2_option_name 		= 'two2_options_pages';
				$two2_settings_page_title = __( 'Pages','two2');
				$two2_page_sections 		= two2_options_pages_sections();
				$two2_page_fields 		= two2_options_pages_fields();
			break;
			
			case TWO2_PAGE_BASENAME . '-style':
				$two2_option_name 		= 'two2_options_style';
				$two2_settings_page_title = __( 'Style','two2');	
				$two2_page_sections 		= two2_options_style_sections();
				$two2_page_fields 		= two2_options_style_fields();
			break;
		}
		
		// put together the output array 
		$output['two2_option_name'] 		= $two2_option_name;
		$output['two2_page_title'] 		= $two2_settings_page_title;
		$output['two2_page_sections'] 	= $two2_page_sections;
		$output['two2_page_fields'] 		= $two2_page_fields;
	}
	return $output;
}

/**
 * Helper function for registering our form field settings
 *
 * src: http://alisothegeek.com/2011/01/wordpress-settings-api-tutorial-1/
 * @param (array) $args The array of arguments to be used in creating the field
 * @return function call
 */
function two2_create_settings_field( $args = array() ) {
	// default array to overwrite when calling the function
	$defaults = array(
		'id'      => 'default_field', 					// the ID of the setting in our options array, and the ID of the HTML form element
		'title'   => 'Default Field', 					// the label for the HTML form element
		'desc'    => '', 	// the description displayed under the HTML form element
		'std'	  => '', 								// the default value for this setting
		'type'    => 'text', 							// the HTML form element to use
		'section' => 'main_section', 					// the section this setting belongs to — must match the array key of a section in two2_options_page_sections()
		'choices' => array(),							// (optional): the choices in drop-down menu
		'values'  => array(), 							// (optional): the values in drop-down menu
		'unit'	  => 'px',
		'screen'  => '',
		'name_sec'=> '',
		'style'	  =>'',
		'in_style'=>'',
		'max_width'=>''
	);
	
	// "extract" to be able to use the array keys as variables in our function output below
	extract( wp_parse_args( $args, $defaults ) );
	
	// additional arguments for use in form field output in the function two2_form_field_fn!
	$field_args = array(
		'type'      => $type,
		'desc'      => $desc,
		'std'       => $std,
		'name'   	=> $name,
		'title'   	=> $title,
		'choices'  	=> $choices,
		'values'   	=> $values,
		'unit'   	=> $unit,
		'screen'  	=> $screen,
		'style'		=> $style,
		'in_style'	=> $in_style,
		'max_width' => $max_width
	);

	add_settings_field( $name, $title, 'two2_form_field_fn', __FILE__, $section, $field_args );

}

/**
 * Register our setting, settings sections and settings fields
 */
function two2_register_settings(){
	
	// get the settings sections array
	$settings_output 	= two2_get_settings();
	if($settings_output){
		$two2_option_name = $settings_output['two2_option_name'];
		
		//setting
		register_setting($two2_option_name, $two2_option_name);
		
		//sections
		if(!empty($settings_output['two2_page_sections'])){
			// call the "add_settings_section" for each!
			foreach ( $settings_output['two2_page_sections'] as $name => $title ) {
				add_settings_section( $name, $title, 'two2_section_fn', __FILE__);
			}
		}
			
		//fields
		if(!empty($settings_output['two2_page_fields'])){
			// call the "add_settings_field" for each!
			foreach ($settings_output['two2_page_fields'] as $option) {
				two2_create_settings_field($option);
			}
		}
	}
}

/**
 * Group scripts (js & css)
 */
function two2_settings_scripts(){

	wp_enqueue_script('media-upload');
	wp_enqueue_script('thickbox');
	wp_enqueue_script('my-upload');
	wp_enqueue_script('jquery-ui', get_template_directory_uri().'/functions/js/jquery-ui-1.8.18.custom.min.js');
	wp_enqueue_script('color-picker', get_template_directory_uri().'/functions/js/colorpicker.js');
	wp_enqueue_script('cycle', get_template_directory_uri().'/functions/js/jquery.cycle.lite.js');
	wp_enqueue_script('framework-options', get_template_directory_uri().'/functions/js/framework-options.js');	
	wp_enqueue_script('theme-options', get_template_directory_uri().'/functions/js/theme-options.js');	

	wp_enqueue_style('thickbox');
	wp_enqueue_style('jquery-ui', get_template_directory_uri().'/functions/css/smoothness/jquery-ui-1.8.18.custom.css');
	wp_enqueue_style('color-picker', get_template_directory_uri().'/functions/css/colorpicker.css');
	wp_enqueue_style('framework-options', get_template_directory_uri().'/functions/css/framework-options.css');
	wp_enqueue_style('theme-options', get_template_directory_uri().'/functions/css/theme-options.css');

}


add_action('admin_print_scripts-post.php', 'two2_settings_scripts');
add_action('admin_print_scripts-post-new.php', 'two2_settings_scripts');


/**
 * The admin menu pages
 */
function two2_add_menu(){
	
	$settings_output 		= two2_get_settings();

	// As a "top level" menu
	add_menu_page( __('Folio Two', 'two2'), __('Folio Two','two2'), 'manage_options', TWO2_PAGE_BASENAME, 'two2_settings_page_fn', get_template_directory_uri().'/images/ico-back.png'); 
	
	// page one
	$two2_settings_page = add_submenu_page(TWO2_PAGE_BASENAME, __('Folio Two / General Options', 'two2'), __('General','two2'), 'manage_options', TWO2_PAGE_BASENAME, 'two2_settings_page_fn');

		// css & js
		add_action( 'load-'. $two2_settings_page, 'two2_settings_scripts' );
	
	
	// style page
	$two2_settings_style = add_submenu_page(TWO2_PAGE_BASENAME, __('Folio Two / Style Options', 'two2'), __('Style','two2'), 'manage_options', TWO2_PAGE_BASENAME . '-style', 'two2_settings_page_fn');

		// css & js
		add_action( 'load-'. $two2_settings_style, 'two2_settings_scripts' );
		
		
	// project page
	$two2_settings_project = add_submenu_page(TWO2_PAGE_BASENAME, __('Folio Two / Project Options', 'two2'), __('Project','two2'), 'manage_options', TWO2_PAGE_BASENAME . '-project', 'two2_settings_page_fn');

		// css & js
		add_action( 'load-'. $two2_settings_project, 'two2_settings_scripts' );
		
		
	// fonts page
	$two2_settings_fonts = add_submenu_page(TWO2_PAGE_BASENAME, __('Folio Two / Fonts Options', 'two2'), __('Fonts','two2'), 'manage_options', TWO2_PAGE_BASENAME . '-fonts', 'two2_settings_page_fn');

		// css & js
		add_action( 'load-'. $two2_settings_fonts, 'two2_settings_scripts' );
		
		
	// pages page
	$two2_settings_pages = add_submenu_page(TWO2_PAGE_BASENAME, __('Folio Two / Page Templates Options', 'two2'), __('Pages','two2'), 'manage_options', TWO2_PAGE_BASENAME . '-pages', 'two2_settings_page_fn');

		// css & js
		add_action( 'load-'. $two2_settings_pages, 'two2_settings_scripts' );
	
}

// ************************************************************************************************************

// Callback functions

/*
 * Section HTML, displayed before the first option
 * @return echoes output
 */
function two2_section_fn($desc) {

}

/**
 * Form Fields HTML
 * All form field types share the same function!!
 * @return echoes output
 */
function two2_form_field_fn($args = array()) {
	
	extract( $args );
	
	// get the settings sections array
	$settings_output 	= two2_get_settings();
	
	$two2_options		= $settings_output['two2_option_name'];
	$two2_option_name = $two2_options.'['.$name.']';
	$options 			= get_option($two2_options);

	// pass the standard value if the option is not yet set in the database
	if ( !isset( $options[$name] ) && 'type' != 'checkbox' ) {
		$options[$name] = $std;
	}
		
	// switch html display based on the setting type.	
	switch ( $type ) {
		case 'select':
		?>
		<select name="<?php print $two2_option_name; ?>">
	  	<?php $i=0; foreach($values as $value){ ?>
			<option value="<?php print $value ?>"<?php if($value == $options[$name]){ ?> selected="selected"<?php } ?>><?php print $choices[$i]; ?></option>
		<?php $i++; } ?></select>
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		break;
		
		case 'text':
		?>
		<input class="regular-text" type="text" name="<?php print $two2_option_name; ?>" value="<?php print $options[$name]; ?>" />
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		break;
		
		case 'textcode':
		?>
		<input class="regular-text code" type="text" name="<?php print $two2_option_name; ?>" value="<?php print $options[$name]; ?>" />
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		break;
		
		case 'checkbox':
		?>
		<input type="checkbox" name="<?php print $two2_option_name; ?>" value="1"<?php if($options[$name]==1){ ?> checked="checked"<?php } ?> />
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		break;
		
		case 'image':
		?>
		<input class="uploadimg" type="text" name="<?php print $two2_option_name; ?>" value="<?php print $options[$name]; ?>" />
		<input class="button uploadbutton" type="button" value="<?php _e("Upload Image","two2"); ?>" />
		<br />
		<?php if($options[$name]){ ?><div class="image_preview bordered_preview rounded_preview"<?php if(isset($style)){ ?> style="<?php print $style; ?>"<?php } ?>><div class="image_preview_inner rounded_preview"<?php if(isset($in_style)){ ?> style="<?php print $in_style; ?>"<?php } ?>><img src="<?php print $options[$name]; ?>" alt="<?php print $title; ?>" /></div></div><?php } ?>
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		break;
		
		case 'imagenopreview':
		?>
		<input class="uploadimg" type="text" name="<?php print $two2_option_name; ?>" value="<?php print $options[$name]; ?>" />
		<input class="button uploadbutton" type="button" value="<?php _e("Upload Image","two2"); ?>" />
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		break;
		
		case 'bgbuttons':
		?>
		<?php if($options[$name.'_custom']!=''){ ?><div class="image_preview rounded_preview bordered_preview bg_preview pattern_preview"><div style="background-image:url('<?php print $options[$name.'_custom']; ?>')"></div></div><?php } ?>
		<?php foreach($values as $value){ ?>
		<div class="image_preview rounded_preview bordered_preview bg_preview pattern_preview"><div<?php if($value=='null'){ ?> class="empty-bg"<?php } else { ?> style="background-image:url('<?php print $value; ?>')"<?php } ?>><?php if($value=='null'){ print '<span>'.__("Disable","two2").'</span>'; } ?></div></div>
		<?php } ?>
		<input type="hidden" value="<?php print $options[$name]; ?>" name="<?php print $two2_option_name; ?>" />
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		break;
		
		case 'imagebuttons':
		?>
		<?php if(isset($options[$name.'_custom'])){ if($options[$name.'_custom']!=''){ ?><div class="image_preview rounded_preview bordered_preview bg_preview"><div class="rounded_preview bordered_preview img_preview"><img src="<?php print $options[$name.'_custom']; ?>" alt="<?php print $title; ?>" /></div></div><?php } } ?>
		<?php foreach($values as $option_value){ ?>
		<div class="image_preview rounded_preview bordered_preview bg_preview"<?php if(isset($max_width)){ ?> style="max-width: <?php print $max_width; ?>px"<?php } ?>><div class="rounded_preview bordered_preview img_preview"><img src="<?php print $option_value; ?>" alt="<?php print $title; ?>" /></div></div>
		<?php } ?>
		<input type="hidden" value="<?php print $options[$name]; ?>" name="<?php print $two2_option_name; ?>" />
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		break;
		
		case 'imageselect':
		?>
		<?php $i=0; foreach($values as $option_value){?>
		<div class="image_select image_preview rounded_preview bordered_preview bg_preview"><div class="rounded_preview bordered_preview img_preview"><img src="<?php print get_template_directory_uri().'/functions/images/'.$option_value.'.png'; ?>" alt="<?php print $option_value; ?>" /><span><?php print $choices[$i]; ?></span></div></div>
		<?php $i++; } ?>
		<input type="hidden" value="<?php print $options[$name]; ?>" name="<?php print $two2_option_name; ?>" />
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		break;
		
		case 'textarea':
		?>
		<textarea class="large-text" name="<?php print $two2_option_name; ?>"><?php print $options[$name]; ?></textarea>
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		break;
		
		case 'textareacode':
		?>
		<textarea class="large-text code" name="<?php print $two2_option_name; ?>"><?php print $options[$name]; ?></textarea>
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		break;
		
		case 'color':
		?>
		<div class="colorpicker-container">
		<div class="color-selector" id="color-selector-1"><div style="background-color: <?php print $options[$name]; ?>"></div></div>
		<input type="hidden" name="<?php print $two2_option_name; ?>" value="<?php print $options[$name]; ?>" />
		</div>
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		break;
		
		case 'slider':
		?>
		<div class="slider slider-unit-<?php print $unit; ?>"><input type="hidden" name="<?php print $two2_option_name; ?>" value="<?php if(!$options[$name]){ print '0'; } else { print $options[$name]; } ?>" />
    	<input type="hidden" name="<?php print $name; ?>_min" value="<?php print $values[0]; ?>" />
    	<input type="hidden" name="<?php print $name; ?>_max" value="<?php print $values[1]; ?>" /></div>
    	<div class="slider-value"></div>
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		break;
		
		case 'typography':	
				
		if($screen){ if(is_array($screen)){ ?><div class="vkw-screen-slider-container"><div class="vkw-screen-slider"><?php foreach($screen as $screen_single){ ?><img class="vkw-screen screen-<?php print $name; ?>" src="<?php print $screen_single; ?>" /><?php } ?></div></div><?php } else { ?><img class="vkw-screen screen-<?php print $name; ?>" src="<?php print $screen; ?>" /><?php } } ?>
		
		<div class="vkw-typography-container">
		<?php if(isset($std['size'])){ ?>
		<select class="vkw-typography vkw-typography-size" name="<?php print $two2_option_name.'[size]'; ?>">
		<?php
		for ($i = 9; $i < 91; $i++) { 
			$size = $i . 'px'; ?>
			<option value="<?php print esc_attr( $size ); ?>"<?php if($size == $options[$name]['size']){ ?> selected="selected"<?php } ?>><?php print esc_html( $size ); ?></option>
		<?php } ?>
		</select>
		
		<?php } if(isset($std['face'])){ ?>
		<select class="vkw-typography vkw-typography-face" name="<?php print $two2_option_name.'[face]'; ?>">
		
		<?php $faces = vankarwai_get_font_list(); 
		foreach ( $faces as $key => $face ){ ?>
			<option value="<?php print esc_attr( $key ); ?>"<?php if($key == $options[$name]['face']){ ?> selected="selected"<?php } ?>><?php print esc_html( $face ); ?></option>
		<?php } ?>			
		
		</select>
		
		<?php } if(isset($std['weight'])){ ?>
		<select class="vkw-typography vkw-typography-weight" name="<?php print $two2_option_name.'[weight]'; ?>">

		<?php $weights = vankarwai_get_font_weights();
		foreach ( $weights as $key => $weight ) { ?>
			<option value="<?php print esc_attr( $key ); ?>"<?php if($key == $options[$name]['weight']){ ?> selected="selected"<?php } ?>><?php print $weight; ?></option>
		<?php 
		}
		?>
		</select>
		
		<?php } if(isset($std['color'])){ ?>
		<div class="colorpicker-container">
		<div class="color-selector" id="color-selector-1"><div style="background-color: <?php print $options[$name]['color']; ?>"></div></div>
		<input type="hidden" name="<?php print $two2_option_name.'[color]'; ?>" value="<?php print $options[$name]['color']; ?>" />
		</div>
		
		<?php } if(isset($std['italic'])){ ?><input type="hidden" name="<?php print $two2_option_name.'[italic]'; ?>" value="" /><label><input class="vkw-typography-italic" type="checkbox"<?php if($options[$name]['italic']==1){ ?> checked="checked"<?php } ?> /> <?php _e("Italic", "two2"); ?></label>
		
		<?php } if(isset($std['uppercase'])){ ?><input type="hidden" name="<?php print $two2_option_name.'[uppercase]'; ?>" value="" /><label><input class="vkw-typography-uppercase" type="checkbox" <?php if($options[$name]['uppercase']==1){ ?> checked="checked"<?php } ?> /> <?php _e("Uppercase", "two2"); ?></label><?php } ?>
		
		<p class="webfont_preview rounded_preview bordered_preview"><span><?php print get_bloginfo('name'); ?></span></p><div class="clear"></div></div>
		<?php echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : ""; 
		
		break;
	}
}

/*
 * Admin Settings Page HTML
 * 
 * @return echoes output
 */
function two2_settings_page_fn() {
	// get the settings sections array
	$settings_output = two2_get_settings();
?>
	<div class="wrap">
		<?php 
		// dislays the page title
		two2_settings_page_header(); 
		?>
		
		<form action="options.php" method="post">
			<?php 
			// http://codex.wordpress.org/Function_Reference/settings_fields
			settings_fields($settings_output['two2_option_name']); 
			// http://codex.wordpress.org/Function_Reference/do_settings_sections
			do_settings_sections(__FILE__); 
			?>
			
			<p class="submit">
				<input name="Submit" type="submit" class="button-primary" value="<?php esc_attr_e('Save Changes','two2'); ?>" />
			</p>
			
		</form>
	</div><!-- wrap -->
<?php }



function two2_validate_options($input) {

	return $input;
}



/**
 * Helper function for creating admin messages
 * src: http://www.wprecipes.com/how-to-show-an-urgent-message-in-the-wordpress-admin-area
 *
 * @param (string) $message The message to echo
 * @param (string) $msgclass The message class
 * @return echoes the message
 */
function two2_show_msg($message, $msgclass = 'info') {
	echo "<div id='message' class='$msgclass'>$message</div>";
}

/**
 * Callback function for displaying admin messages
 *
 * @return calls two2_show_msg()
 */
function two2_admin_msgs() {
	
	if(isset($_GET['page'])){ 
		// check for our settings page - need this in conditional further down
		$two2_settings_pg = strpos($_GET['page'], TWO2_PAGE_BASENAME);
		// collect setting errors/notices: //http://codex.wordpress.org/Function_Reference/get_settings_errors
		$set_errors = get_settings_errors(); 
		
		//display admin message only for the admin to see, only on our settings page and only when setting errors/notices are returned!	
		if(current_user_can ('manage_options') && $two2_settings_pg !== FALSE && !empty($set_errors)){
	
			// have our settings succesfully been updated? 
			if($set_errors[0]['code'] == 'settings_updated' && isset($_GET['settings-updated'])){
				two2_show_msg("<p>" . $set_errors[0]['message'] . "</p>", 'updated');
			
			// have errors been found?
			}else{
				// there maybe more than one so run a foreach loop.
				foreach($set_errors as $set_error){
					// set the title attribute to match the error "setting title" - need this in js file
					two2_show_msg("<p class='setting-error-message' title='" . $set_error['setting'] . "'>" . $set_error['message'] . "</p>", 'error');
				}
			}
		}
	}
}

// admin messages hook!
add_action('admin_notices', 'two2_admin_msgs');


/**
 * Helper function: Check for pages and return the current page name
 *
 * @return string
 */
function two2_get_admin_page() {

	global $pagenow;
	
	$current_page = "";
	
	if(isset($_GET['page'])){ $current_page = trim($_GET['page']); }
	
	// use a different way to read the current page name when the form submits
	if ($pagenow == 'options.php') {
		// get the page name
		$parts 	= explode('page=', $_POST['_wp_http_referer']); // http://codex.wordpress.org/Function_Reference/wp_referer_field
		$page  	= $parts[1]; 
		$page	= explode('&', $page);
		$page	= $page[0];
		$current_page = trim($page);
	} 

	return $current_page;

}



/**
 * Helper function: Creates settings page title
 *
 * @return echos output
 */
function two2_settings_page_header() {
	
    $settings_output 	= two2_get_settings();
		
	// display the icon and page title
	echo '<div id="icon-options-general" class="icon32"><br /></div>';
	echo '<h2>' . get_bloginfo('name') .' / '.sprintf(__('%s Options','two2'), $settings_output['two2_page_title']) . '</h2>';
   
}



function vankarwai_get_font_list() {
	$default = array(
		'Arial'     				=> 'Arial (S)',
		'Verdana'   				=> 'Verdana, Geneva (S)',
		'Trebuchet, Trebuchet MS' 	=> 'Trebuchet (S)',
		'Georgia'   				=> 'Georgia (S)',
		'Times'     				=> 'Times New Roman (S)',
		'Tahoma'    				=> 'Tahoma, Geneva (S)',
		'Palatino'  				=> 'Palatino (S)',
		'Helvetica Neue, HelveticaNeue, Helvetica-Neue, Helvetica'	=> 'Helvetica (S)',
		'Abel'    					=> 'Abel (G)',
		'Abril Fatfac'				=> 'Abril Fatfac (G)',
		'Advent Pro'				=> 'Advent Pro (G)',
		'Alfa Slab One'				=> 'Alfa Slab One (G)',
		'Alice'						=> 'Alice (G)',
		'Alike'						=> 'Alike (G)',
		'Antic'						=> 'Antic (G)',	
		'Artifika'					=> 'Artifika (G)',
		'Arvo'						=> 'Arvo (G)',
		'Balthazar'					=> 'Balthazar (G)',
		'Bevan'						=> 'Bevan (G)',
		'Bowlby One SC'				=> 'Bowlby One SC (G)',
		'Bree Serif'				=> 'Bree Serif (G)',
		'Cantata One'				=> 'Cantata One (G)',
		'Condiment'					=> 'Condiment (G)',
		'Coustard'					=> 'Coustard (G)',
		'Crete Round'				=> 'Crete Round (G)',
		'Cutive'					=> 'Cutive (G)',
		'Dosis'						=> 'Dosis (G)',
		'Economica'					=> 'Economica (G)',
		'Fjord One'					=> 'Fjord One (G)',
		'Flamenco'					=> 'Flamenco (G)',
		'Glass Antiqua'				=> 'Glass Antiqua (G)',
		'Glegoo'					=> 'Glegoo (G)',
		'Gravitas One'				=> 'Gravitas One (G)',
		'Holtwood One SC'			=> 'Holtwood One SC (G)',
		'IM Fell DW Pica SC'		=> 'IM Fell DW Pica SC (G)',
		'Inika'						=> 'Inika (G)',
		'Josefin Sans'				=> 'Josefin Sans (G)',
		'Kameron'					=> 'Kameron (G)',
		'Kelly Slab'				=> 'Kelly Slab (G)',
		'Lancelot'					=> 'Lancelot (G)',
		'Lekton'					=> 'Lekton (G)',
		'Limelight'					=> 'Limelight (G)',
		'Linden Hill'				=> 'Linden Hill (G)',
		'Lobster Two'				=> 'Lobster Two (G)',
		'Lustria'					=> 'Lustria (G)',
		'Maven Pro'					=> 'Maven Pro (G)',
		'Megrim'					=> 'Megrim (G)',
		'Molengo'					=> 'Molengo (G)',
		'Nobile'					=> 'Nobile (G)',
		'Noticia Text'				=> 'Noticia Text (G)',
		'Old Standard TT'			=> 'Old Standard TT (G)',
		'Oldenburg'					=> 'Oldenburg (G)',
		'Patua One'					=> 'Patua One (G)',
		'Paytone One'				=> 'Paytone One (G)',
		'Playfair Display'			=> 'Playfair Display (G)',
		'Poiret One'				=> 'Poiret One (G)',
		'Port Lligat Slab'			=> 'Port Lligat Slab (G)',
		'PT Sans Narrow'			=> 'PT Sans Narrow (G)',
		'PT Serif'					=> 'PT Serif (G)',
		'Radley'					=> 'Radley (G)',
		'Raleway'					=> 'Raleway (G)',
		'Rokkitt'					=> 'Rokkitt (G)',
		'Satisfy'					=> 'Satisfy (G)',
		'Seaweed Script'			=> 'Seaweed Script (G)',
		'Simonetta'					=> 'Simonetta (G)',
		'Sonsie One'				=> 'Sonsie One (G)',
		'Sorts Mill Goudy'			=> 'Sorts Mill Goudy (G)',
		'Stint Ultra Expanded'		=> 'Stint Ultra Expanded (G)',
		'Tienne'					=> 'Tienne (G)',
		'Tinos'						=> 'Tinos (G)',
		'Ultra'						=> 'Ultra (G)',
		'Vidaloka'					=> 'Vidaloka (G)'
		);
		
	return $default;
}


function vankarwai_get_font_weights() {
	$default = array(
		'200'			=> 'Light',
		'normal'      	=> 'Normal',
		'bold'        	=> 'Bold',
		'300' 			=> '300',
		'400' 			=> '400',
		'500' 			=> '500',
		'600' 			=> '600',
		'700' 			=> '700'
		);
		
	return $default;
}



// ===================== 
// ! AJAX  
// ===================== 

add_action('wp_ajax_vankarwai_load_font', 'vankarwai_load_font');

function vankarwai_load_font(){
	print vankarwai_get_google_webfont($_POST['font']);
	die();
}



?>